@@ -1,7 +1,7 @@
 from contextlib import suppress
 from typing import Any, Dict, List, Tuple, Union
 
-import base58  # type: ignore
+import base58
 import strict_rfc3339  # type: ignore
 
 from pytezos.crypto.encoding import base58_decode, base58_encode
@@ -347,15 +347,12 @@ def unforge_micheline(data: bytes) -> Union[List, Dict]:
         else:
             assert args_len == 0, f'unexpected args len {args_len}'
 
-        if annots:
+        if annots or args_len == 3:
             value, offset = unforge_array(data[ptr:])
             ptr += offset
             if len(value) > 0:
                 expr['annots'] = value.decode().split(' ')
 
-        if args_len == 3:
-            ptr += 4
-
         return expr
 
     def unforge():
