@@ -1,6 +1,6 @@
 from typing import Any, Dict, List, Optional, Type, Union, cast
 
-from pytezos.context.abstract import AbstractContext  # type: ignore
+from pytezos.context.abstract import AbstractContext
 from pytezos.michelson.micheline import Micheline, MichelsonRuntimeError
 from pytezos.michelson.types import OrType
 from pytezos.michelson.types.adt import wrap_or, wrap_parameters
