@@ -1,6 +1,6 @@
 from typing import Type
 
-from pytezos.context.abstract import AbstractContext  # type: ignore
+from pytezos.context.abstract import AbstractContext
 from pytezos.michelson.micheline import Micheline, MichelineLiteral, blind_unpack, parse_micheline_literal, parse_micheline_value
 from pytezos.michelson.types.base import MichelsonType
 
